Learn R Programming

PSICQUIC (version 1.10.0)

providers: providers

Description

The central PSICQUIC server has only one purpose: to return a list of, and metadata about, the currently "live" PSICQUIC-compliant MI-QL websites. A list of these providers by the PSICQUIC object you create, and is returned by this method.

Usage

"providers"(object)

Arguments

object
a PSICQUIC object.

Value

A list of character strings, short readable names for the providers, e.g., "BioGrid", "IntAct".

See Also

interactions, rawQuery, addGeneInfo, IDMapper, interactionTypes, detectionMethods, speciesIDs

Examples

Run this code
  psicquic <- PSICQUIC()
  providers(psicquic)

Run the code above in your browser using DataLab