interactionTypes will drive your web browser to a EMBL-EBI Ontology
Lookup Service devoted to protein-protein interaction types.
detectionMethods will drive your web browser to a EMBL-EBI Ontology
Lookup Service devoted to protein interaction detection methods.
speciesIDs helps in finding the NCBI taxon ids which are used to identify species (e.g., "9606" for Homo
sapiens). This method drives your web browser to the NCBI Taxonomy
Browser (the NCBI Taxonomy Homepage), where you can use the search
facilities to obtain the taxon id for your organism/s of interest.